@@ -116,15 +116,31 @@ class Plugin(Plugin_Base):
         items = []
         items.append('<meta name="markdown-generator" content="teedoc-plugin-markdown-parser">')
         return items
-    
+
     def _update_link(self, content):
         def re_del(c):
-            ret = c[0].replace(".md", ".html") 
-            ret = re.sub("README.md", "index.html", c[0], flags=re.I)
-            ret = re.sub(r".md", ".html", ret, re.I)
+            ret = c[0]
+            links = re.findall('\((.*?)\)', c[0])
+            if len(links) > 0:
+                for link in links:
+                    if link.startswith(".") or os.path.isabs(link):
+                        ret = re.sub("README.md", "index.html", c[0], flags=re.I)
+                        ret = re.sub(r".md", ".html", ret, re.I)
+                        return ret
             return ret
-
+        def re_del_ipynb(c):
+            ret = c[0]
+            links = re.findall('\((.*?)\)', c[0])
+            if len(links) > 0:
+                for link in links:
+                    if link.startswith(".") or os.path.isabs(link):
+                        ret = re.sub("README.ipynb", "index.html", c[0], flags=re.I)
+                        ret = re.sub(r".ipynb", ".html", ret, re.I)
+                        return ret
+            return ret
+        # <a class="anchor-link" href="#&#38142;&#25509;"> </a></h2><p><a href="./syntax_markdown.md">markdown 语法</a>
         content = re.sub(r'\[.*?\]\(.*?\.md\)', re_del, content, flags=re.I)
+        content = re.sub(r'\[.*?\]\(.*?\.ipynb\)', re_del_ipynb, content, flags=re.I)
         return content
 
 if __name__ == "__main__":
